@@ -8,8 +8,8 @@ from django.conf import settings
 
 from pages import settings as pages_settings
 from pages.models import Content, Page
-from pages.placeholders import PlaceholderNode, ImagePlaceholderNode
-from pages.placeholders import VideoPlaceholderNode
+from pages.placeholders import PlaceholderNode, ImagePlaceholderNode, FilePlaceholderNode
+from pages.placeholders import VideoPlaceholderNode, ContactPlaceholderNode
 from pages.placeholders import parse_placeholder
 
 register = template.Library()
@@ -444,6 +444,13 @@ def do_imageplaceholder(parser, token):
     return ImagePlaceholderNode(name, **params)
 register.tag('imageplaceholder', do_imageplaceholder)
 
+def do_fileplaceholder(parser, token):
+    """
+    Method that parse the fileplaceholder template tag.
+    """
+    name, params = parse_placeholder(parser, token)
+    return FilePlaceholderNode(name, **params)
+register.tag('fileplaceholder', do_fileplaceholder)
 
 def do_videoplaceholder(parser, token):
     """
@@ -453,6 +460,14 @@ def do_videoplaceholder(parser, token):
     return VideoPlaceholderNode(name, **params)
 register.tag('videoplaceholder', do_videoplaceholder)
 
+def do_contactplaceholder(parser, token):
+    """
+    Method that parse the contactplaceholder template tag.
+    """
+    name, params = parse_placeholder(parser, token)
+    return ContactPlaceholderNode(name, **params)
+register.tag('contactplaceholder', do_contactplaceholder)
+
 
 def language_content_up_to_date(page, language):
     """Tell if all the page content has been updated since the last
