@@ -59,7 +59,8 @@ FIXTURE_DIRS = [os.path.join(PROJECT_DIR, 'fixtures')]
 SECRET_KEY = '*xq7m@)*f2awoj!spa0(jibsrz9%c0d=e(g)v*!17y(vx0ue_3'
 
 TEMPLATE_CONTEXT_PROCESSORS = (
-    "django.contrib.auth.context_processors.auth",
+    # fails on Django 1.1.4
+    #"django.contrib.auth.context_processors.auth",
     'django.core.context_processors.auth',
     "django.core.context_processors.i18n",
     "django.core.context_processors.debug",
@@ -145,6 +146,7 @@ PAGE_LANGUAGES = (
 languages = list(PAGE_LANGUAGES)
 languages.append(('fr-fr', gettext_noop('French')))
 languages.append(('fr-be', gettext_noop('Belgium french')))
+languages.append(('it-it', gettext_noop('Italian')))
 LANGUAGES = languages
 
 # This enable you to map a language(s) to another one, these languages should
